#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CdpDisplayContent(object):

    def __init__(self):
        self._action_url = None
        self._ext_info = None
        self._gmt_end = None
        self._gmt_start = None
        self._image_url = None
        self._text = None
        self._type = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def image_url(self):
        return self._image_url

    @image_url.setter
    def image_url(self, value):
        self._image_url = value
    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, value):
        self._text = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_start:
            if hasattr(self.gmt_start, 'to_alipay_dict'):
                params['gmt_start'] = self.gmt_start.to_alipay_dict()
            else:
                params['gmt_start'] = self.gmt_start
        if self.image_url:
            if hasattr(self.image_url, 'to_alipay_dict'):
                params['image_url'] = self.image_url.to_alipay_dict()
            else:
                params['image_url'] = self.image_url
        if self.text:
            if hasattr(self.text, 'to_alipay_dict'):
                params['text'] = self.text.to_alipay_dict()
            else:
                params['text'] = self.text
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CdpDisplayContent()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_start' in d:
            o.gmt_start = d['gmt_start']
        if 'image_url' in d:
            o.image_url = d['image_url']
        if 'text' in d:
            o.text = d['text']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringOrderRefundModel(object):

    def __init__(self):
        self._amount = None
        self._ext_info = None
        self._order_id = None
        self._out_biz_no = None
        self._reason = None
        self._request_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringOrderRefundModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'reason' in d:
            o.reason = d['reason']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankMarketingMcaplatformLevelQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankMarketingMcaplatformLevelQueryResponse, self).__init__()
        self._green_level = None
        self._growth_value = None

    @property
    def green_level(self):
        return self._green_level

    @green_level.setter
    def green_level(self, value):
        self._green_level = value
    @property
    def growth_value(self):
        return self._growth_value

    @growth_value.setter
    def growth_value(self, value):
        self._growth_value = value

    def parse_response_content(self, response_content):
        response = super(MybankMarketingMcaplatformLevelQueryResponse, self).parse_response_content(response_content)
        if 'green_level' in response:
            self.green_level = response['green_level']
        if 'growth_value' in response:
            self.growth_value = response['growth_value']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NewsfeedLabelInfo(object):

    def __init__(self):
        self._action = None
        self._scheme = None
        self._target = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def scheme(self):
        return self._scheme

    @scheme.setter
    def scheme(self, value):
        self._scheme = value
    @property
    def target(self):
        return self._target

    @target.setter
    def target(self, value):
        self._target = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.scheme:
            if hasattr(self.scheme, 'to_alipay_dict'):
                params['scheme'] = self.scheme.to_alipay_dict()
            else:
                params['scheme'] = self.scheme
        if self.target:
            if hasattr(self.target, 'to_alipay_dict'):
                params['target'] = self.target.to_alipay_dict()
            else:
                params['target'] = self.target
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NewsfeedLabelInfo()
        if 'action' in d:
            o.action = d['action']
        if 'scheme' in d:
            o.scheme = d['scheme']
        if 'target' in d:
            o.target = d['target']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccessOrdersFeedBack import AccessOrdersFeedBack


class KoubeiSalesKbassetStuffOrdersresultSyncModel(object):

    def __init__(self):
        self._orders_feedback = None

    @property
    def orders_feedback(self):
        return self._orders_feedback

    @orders_feedback.setter
    def orders_feedback(self, value):
        if isinstance(value, list):
            self._orders_feedback = list()
            for i in value:
                if isinstance(i, AccessOrdersFeedBack):
                    self._orders_feedback.append(i)
                else:
                    self._orders_feedback.append(AccessOrdersFeedBack.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.orders_feedback:
            if isinstance(self.orders_feedback, list):
                for i in range(0, len(self.orders_feedback)):
                    element = self.orders_feedback[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.orders_feedback[i] = element.to_alipay_dict()
            if hasattr(self.orders_feedback, 'to_alipay_dict'):
                params['orders_feedback'] = self.orders_feedback.to_alipay_dict()
            else:
                params['orders_feedback'] = self.orders_feedback
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiSalesKbassetStuffOrdersresultSyncModel()
        if 'orders_feedback' in d:
            o.orders_feedback = d['orders_feedback']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceLogisticsOrderIstdcancelPreconsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceLogisticsOrderIstdcancelPreconsultResponse, self).__init__()
        self._allow_cancel = None

    @property
    def allow_cancel(self):
        return self._allow_cancel

    @allow_cancel.setter
    def allow_cancel(self, value):
        self._allow_cancel = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceLogisticsOrderIstdcancelPreconsultResponse, self).parse_response_content(response_content)
        if 'allow_cancel' in response:
            self.allow_cancel = response['allow_cancel']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DevicePushPayload(object):

    def __init__(self):
        self._device_id = None
        self._notify_params = None
        self._scene = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def notify_params(self):
        return self._notify_params

    @notify_params.setter
    def notify_params(self, value):
        self._notify_params = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.notify_params:
            if hasattr(self.notify_params, 'to_alipay_dict'):
                params['notify_params'] = self.notify_params.to_alipay_dict()
            else:
                params['notify_params'] = self.notify_params
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DevicePushPayload()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'notify_params' in d:
            o.notify_params = d['notify_params']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsMktFactorDTO import InsMktFactorDTO
from alipay.aop.api.domain.InsMktCouponCmpgnBaseDTO import InsMktCouponCmpgnBaseDTO
from alipay.aop.api.domain.InsMktCouponBaseDTO import InsMktCouponBaseDTO
from alipay.aop.api.domain.InsMktObjectDTO import InsMktObjectDTO


class AlipayInsMarketingDiscountPreuseModel(object):

    def __init__(self):
        self._account_id = None
        self._account_type = None
        self._business_type = None
        self._factors = None
        self._market_types = None
        self._mkt_coupon_campaigns = None
        self._mkt_coupons = None
        self._mkt_objects = None
        self._request_id = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def business_type(self):
        return self._business_type

    @business_type.setter
    def business_type(self, value):
        self._business_type = value
    @property
    def factors(self):
        return self._factors

    @factors.setter
    def factors(self, value):
        if isinstance(value, list):
            self._factors = list()
            for i in value:
                if isinstance(i, InsMktFactorDTO):
                    self._factors.append(i)
                else:
                    self._factors.append(InsMktFactorDTO.from_alipay_dict(i))
    @property
    def market_types(self):
        return self._market_types

    @market_types.setter
    def market_types(self, value):
        if isinstance(value, list):
            self._market_types = list()
            for i in value:
                self._market_types.append(i)
    @property
    def mkt_coupon_campaigns(self):
        return self._mkt_coupon_campaigns

    @mkt_coupon_campaigns.setter
    def mkt_coupon_campaigns(self, value):
        if isinstance(value, list):
            self._mkt_coupon_campaigns = list()
            for i in value:
                if isinstance(i, InsMktCouponCmpgnBaseDTO):
                    self._mkt_coupon_campaigns.append(i)
                else:
                    self._mkt_coupon_campaigns.append(InsMktCouponCmpgnBaseDTO.from_alipay_dict(i))
    @property
    def mkt_coupons(self):
        return self._mkt_coupons

    @mkt_coupons.setter
    def mkt_coupons(self, value):
        if isinstance(value, list):
            self._mkt_coupons = list()
            for i in value:
                if isinstance(i, InsMktCouponBaseDTO):
                    self._mkt_coupons.append(i)
                else:
                    self._mkt_coupons.append(InsMktCouponBaseDTO.from_alipay_dict(i))
    @property
    def mkt_objects(self):
        return self._mkt_objects

    @mkt_objects.setter
    def mkt_objects(self, value):
        if isinstance(value, list):
            self._mkt_objects = list()
            for i in value:
                if isinstance(i, InsMktObjectDTO):
                    self._mkt_objects.append(i)
                else:
                    self._mkt_objects.append(InsMktObjectDTO.from_alipay_dict(i))
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.business_type:
            if hasattr(self.business_type, 'to_alipay_dict'):
                params['business_type'] = self.business_type.to_alipay_dict()
            else:
                params['business_type'] = self.business_type
        if self.factors:
            if isinstance(self.factors, list):
                for i in range(0, len(self.factors)):
                    element = self.factors[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.factors[i] = element.to_alipay_dict()
            if hasattr(self.factors, 'to_alipay_dict'):
                params['factors'] = self.factors.to_alipay_dict()
            else:
                params['factors'] = self.factors
        if self.market_types:
            if isinstance(self.market_types, list):
                for i in range(0, len(self.market_types)):
                    element = self.market_types[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.market_types[i] = element.to_alipay_dict()
            if hasattr(self.market_types, 'to_alipay_dict'):
                params['market_types'] = self.market_types.to_alipay_dict()
            else:
                params['market_types'] = self.market_types
        if self.mkt_coupon_campaigns:
            if isinstance(self.mkt_coupon_campaigns, list):
                for i in range(0, len(self.mkt_coupon_campaigns)):
                    element = self.mkt_coupon_campaigns[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.mkt_coupon_campaigns[i] = element.to_alipay_dict()
            if hasattr(self.mkt_coupon_campaigns, 'to_alipay_dict'):
                params['mkt_coupon_campaigns'] = self.mkt_coupon_campaigns.to_alipay_dict()
            else:
                params['mkt_coupon_campaigns'] = self.mkt_coupon_campaigns
        if self.mkt_coupons:
            if isinstance(self.mkt_coupons, list):
                for i in range(0, len(self.mkt_coupons)):
                    element = self.mkt_coupons[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.mkt_coupons[i] = element.to_alipay_dict()
            if hasattr(self.mkt_coupons, 'to_alipay_dict'):
                params['mkt_coupons'] = self.mkt_coupons.to_alipay_dict()
            else:
                params['mkt_coupons'] = self.mkt_coupons
        if self.mkt_objects:
            if isinstance(self.mkt_objects, list):
                for i in range(0, len(self.mkt_objects)):
                    element = self.mkt_objects[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.mkt_objects[i] = element.to_alipay_dict()
            if hasattr(self.mkt_objects, 'to_alipay_dict'):
                params['mkt_objects'] = self.mkt_objects.to_alipay_dict()
            else:
                params['mkt_objects'] = self.mkt_objects
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsMarketingDiscountPreuseModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'business_type' in d:
            o.business_type = d['business_type']
        if 'factors' in d:
            o.factors = d['factors']
        if 'market_types' in d:
            o.market_types = d['market_types']
        if 'mkt_coupon_campaigns' in d:
            o.mkt_coupon_campaigns = d['mkt_coupon_campaigns']
        if 'mkt_coupons' in d:
            o.mkt_coupons = d['mkt_coupons']
        if 'mkt_objects' in d:
            o.mkt_objects = d['mkt_objects']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeAppPayResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeAppPayResponse, self).__init__()
        self._credit_agreement_id = None
        self._credit_biz_order_id = None
        self._credit_pay_mode = None
        self._merchant_order_no = None
        self._out_trade_no = None
        self._seller_id = None
        self._total_amount = None
        self._trade_no = None

    @property
    def credit_agreement_id(self):
        return self._credit_agreement_id

    @credit_agreement_id.setter
    def credit_agreement_id(self, value):
        self._credit_agreement_id = value
    @property
    def credit_biz_order_id(self):
        return self._credit_biz_order_id

    @credit_biz_order_id.setter
    def credit_biz_order_id(self, value):
        self._credit_biz_order_id = value
    @property
    def credit_pay_mode(self):
        return self._credit_pay_mode

    @credit_pay_mode.setter
    def credit_pay_mode(self, value):
        self._credit_pay_mode = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeAppPayResponse, self).parse_response_content(response_content)
        if 'credit_agreement_id' in response:
            self.credit_agreement_id = response['credit_agreement_id']
        if 'credit_biz_order_id' in response:
            self.credit_biz_order_id = response['credit_biz_order_id']
        if 'credit_pay_mode' in response:
            self.credit_pay_mode = response['credit_pay_mode']
        if 'merchant_order_no' in response:
            self.merchant_order_no = response['merchant_order_no']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'seller_id' in response:
            self.seller_id = response['seller_id']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransInvoiceSyncdataModifyModel(object):

    def __init__(self):
        self._amount = None
        self._area = None
        self._file_type = None
        self._invoice_code = None
        self._invoice_name = None
        self._invoice_number = None
        self._invoice_type = None
        self._is_block = None
        self._is_old_data_sync = None
        self._open_biz_no = None
        self._party_code = None
        self._party_name = None
        self._payer_id = None
        self._payer_id_type = None
        self._payer_id_value = None
        self._payer_name = None
        self._status = None
        self._time = None
        self._type = None
        self._url = None
        self._user_id = None
        self._verify = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def area(self):
        return self._area

    @area.setter
    def area(self, value):
        self._area = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_name(self):
        return self._invoice_name

    @invoice_name.setter
    def invoice_name(self, value):
        self._invoice_name = value
    @property
    def invoice_number(self):
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, value):
        self._invoice_number = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def is_block(self):
        return self._is_block

    @is_block.setter
    def is_block(self, value):
        self._is_block = value
    @property
    def is_old_data_sync(self):
        return self._is_old_data_sync

    @is_old_data_sync.setter
    def is_old_data_sync(self, value):
        self._is_old_data_sync = value
    @property
    def open_biz_no(self):
        return self._open_biz_no

    @open_biz_no.setter
    def open_biz_no(self, value):
        self._open_biz_no = value
    @property
    def party_code(self):
        return self._party_code

    @party_code.setter
    def party_code(self, value):
        self._party_code = value
    @property
    def party_name(self):
        return self._party_name

    @party_name.setter
    def party_name(self, value):
        self._party_name = value
    @property
    def payer_id(self):
        return self._payer_id

    @payer_id.setter
    def payer_id(self, value):
        self._payer_id = value
    @property
    def payer_id_type(self):
        return self._payer_id_type

    @payer_id_type.setter
    def payer_id_type(self, value):
        self._payer_id_type = value
    @property
    def payer_id_value(self):
        return self._payer_id_value

    @payer_id_value.setter
    def payer_id_value(self, value):
        self._payer_id_value = value
    @property
    def payer_name(self):
        return self._payer_name

    @payer_name.setter
    def payer_name(self, value):
        self._payer_name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def verify(self):
        return self._verify

    @verify.setter
    def verify(self, value):
        self._verify = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.area:
            if hasattr(self.area, 'to_alipay_dict'):
                params['area'] = self.area.to_alipay_dict()
            else:
                params['area'] = self.area
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_name:
            if hasattr(self.invoice_name, 'to_alipay_dict'):
                params['invoice_name'] = self.invoice_name.to_alipay_dict()
            else:
                params['invoice_name'] = self.invoice_name
        if self.invoice_number:
            if hasattr(self.invoice_number, 'to_alipay_dict'):
                params['invoice_number'] = self.invoice_number.to_alipay_dict()
            else:
                params['invoice_number'] = self.invoice_number
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.is_block:
            if hasattr(self.is_block, 'to_alipay_dict'):
                params['is_block'] = self.is_block.to_alipay_dict()
            else:
                params['is_block'] = self.is_block
        if self.is_old_data_sync:
            if hasattr(self.is_old_data_sync, 'to_alipay_dict'):
                params['is_old_data_sync'] = self.is_old_data_sync.to_alipay_dict()
            else:
                params['is_old_data_sync'] = self.is_old_data_sync
        if self.open_biz_no:
            if hasattr(self.open_biz_no, 'to_alipay_dict'):
                params['open_biz_no'] = self.open_biz_no.to_alipay_dict()
            else:
                params['open_biz_no'] = self.open_biz_no
        if self.party_code:
            if hasattr(self.party_code, 'to_alipay_dict'):
                params['party_code'] = self.party_code.to_alipay_dict()
            else:
                params['party_code'] = self.party_code
        if self.party_name:
            if hasattr(self.party_name, 'to_alipay_dict'):
                params['party_name'] = self.party_name.to_alipay_dict()
            else:
                params['party_name'] = self.party_name
        if self.payer_id:
            if hasattr(self.payer_id, 'to_alipay_dict'):
                params['payer_id'] = self.payer_id.to_alipay_dict()
            else:
                params['payer_id'] = self.payer_id
        if self.payer_id_type:
            if hasattr(self.payer_id_type, 'to_alipay_dict'):
                params['payer_id_type'] = self.payer_id_type.to_alipay_dict()
            else:
                params['payer_id_type'] = self.payer_id_type
        if self.payer_id_value:
            if hasattr(self.payer_id_value, 'to_alipay_dict'):
                params['payer_id_value'] = self.payer_id_value.to_alipay_dict()
            else:
                params['payer_id_value'] = self.payer_id_value
        if self.payer_name:
            if hasattr(self.payer_name, 'to_alipay_dict'):
                params['payer_name'] = self.payer_name.to_alipay_dict()
            else:
                params['payer_name'] = self.payer_name
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.time:
            if hasattr(self.time, 'to_alipay_dict'):
                params['time'] = self.time.to_alipay_dict()
            else:
                params['time'] = self.time
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.verify:
            if hasattr(self.verify, 'to_alipay_dict'):
                params['verify'] = self.verify.to_alipay_dict()
            else:
                params['verify'] = self.verify
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransInvoiceSyncdataModifyModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'area' in d:
            o.area = d['area']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_name' in d:
            o.invoice_name = d['invoice_name']
        if 'invoice_number' in d:
            o.invoice_number = d['invoice_number']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'is_block' in d:
            o.is_block = d['is_block']
        if 'is_old_data_sync' in d:
            o.is_old_data_sync = d['is_old_data_sync']
        if 'open_biz_no' in d:
            o.open_biz_no = d['open_biz_no']
        if 'party_code' in d:
            o.party_code = d['party_code']
        if 'party_name' in d:
            o.party_name = d['party_name']
        if 'payer_id' in d:
            o.payer_id = d['payer_id']
        if 'payer_id_type' in d:
            o.payer_id_type = d['payer_id_type']
        if 'payer_id_value' in d:
            o.payer_id_value = d['payer_id_value']
        if 'payer_name' in d:
            o.payer_name = d['payer_name']
        if 'status' in d:
            o.status = d['status']
        if 'time' in d:
            o.time = d['time']
        if 'type' in d:
            o.type = d['type']
        if 'url' in d:
            o.url = d['url']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'verify' in d:
            o.verify = d['verify']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAgreementPermissionCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAgreementPermissionCreateResponse, self).__init__()
        self._deduct_permission = None
        self._effective_time_end = None
        self._effective_time_start = None

    @property
    def deduct_permission(self):
        return self._deduct_permission

    @deduct_permission.setter
    def deduct_permission(self, value):
        self._deduct_permission = value
    @property
    def effective_time_end(self):
        return self._effective_time_end

    @effective_time_end.setter
    def effective_time_end(self, value):
        self._effective_time_end = value
    @property
    def effective_time_start(self):
        return self._effective_time_start

    @effective_time_start.setter
    def effective_time_start(self, value):
        self._effective_time_start = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAgreementPermissionCreateResponse, self).parse_response_content(response_content)
        if 'deduct_permission' in response:
            self.deduct_permission = response['deduct_permission']
        if 'effective_time_end' in response:
            self.effective_time_end = response['effective_time_end']
        if 'effective_time_start' in response:
            self.effective_time_start = response['effective_time_start']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishInfo import KbdishInfo


class PaginationDish(object):

    def __init__(self):
        self._list = None
        self._page_no = None
        self._page_size = None
        self._total_count = None
        self._total_page = None

    @property
    def list(self):
        return self._list

    @list.setter
    def list(self, value):
        if isinstance(value, list):
            self._list = list()
            for i in value:
                if isinstance(i, KbdishInfo):
                    self._list.append(i)
                else:
                    self._list.append(KbdishInfo.from_alipay_dict(i))
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value
    @property
    def total_page(self):
        return self._total_page

    @total_page.setter
    def total_page(self, value):
        self._total_page = value


    def to_alipay_dict(self):
        params = dict()
        if self.list:
            if isinstance(self.list, list):
                for i in range(0, len(self.list)):
                    element = self.list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.list[i] = element.to_alipay_dict()
            if hasattr(self.list, 'to_alipay_dict'):
                params['list'] = self.list.to_alipay_dict()
            else:
                params['list'] = self.list
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.total_count:
            if hasattr(self.total_count, 'to_alipay_dict'):
                params['total_count'] = self.total_count.to_alipay_dict()
            else:
                params['total_count'] = self.total_count
        if self.total_page:
            if hasattr(self.total_page, 'to_alipay_dict'):
                params['total_page'] = self.total_page.to_alipay_dict()
            else:
                params['total_page'] = self.total_page
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaginationDish()
        if 'list' in d:
            o.list = d['list']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'total_count' in d:
            o.total_count = d['total_count']
        if 'total_page' in d:
            o.total_page = d['total_page']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QuestInstanceDTO(object):

    def __init__(self):
        self._action_schema = None
        self._day_count = None
        self._icon = None
        self._instance_id = None
        self._join_count = None
        self._joined = None
        self._marked = None
        self._quest_id = None
        self._title = None

    @property
    def action_schema(self):
        return self._action_schema

    @action_schema.setter
    def action_schema(self, value):
        self._action_schema = value
    @property
    def day_count(self):
        return self._day_count

    @day_count.setter
    def day_count(self, value):
        self._day_count = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def instance_id(self):
        return self._instance_id

    @instance_id.setter
    def instance_id(self, value):
        self._instance_id = value
    @property
    def join_count(self):
        return self._join_count

    @join_count.setter
    def join_count(self, value):
        self._join_count = value
    @property
    def joined(self):
        return self._joined

    @joined.setter
    def joined(self, value):
        self._joined = value
    @property
    def marked(self):
        return self._marked

    @marked.setter
    def marked(self, value):
        self._marked = value
    @property
    def quest_id(self):
        return self._quest_id

    @quest_id.setter
    def quest_id(self, value):
        self._quest_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_schema:
            if hasattr(self.action_schema, 'to_alipay_dict'):
                params['action_schema'] = self.action_schema.to_alipay_dict()
            else:
                params['action_schema'] = self.action_schema
        if self.day_count:
            if hasattr(self.day_count, 'to_alipay_dict'):
                params['day_count'] = self.day_count.to_alipay_dict()
            else:
                params['day_count'] = self.day_count
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.instance_id:
            if hasattr(self.instance_id, 'to_alipay_dict'):
                params['instance_id'] = self.instance_id.to_alipay_dict()
            else:
                params['instance_id'] = self.instance_id
        if self.join_count:
            if hasattr(self.join_count, 'to_alipay_dict'):
                params['join_count'] = self.join_count.to_alipay_dict()
            else:
                params['join_count'] = self.join_count
        if self.joined:
            if hasattr(self.joined, 'to_alipay_dict'):
                params['joined'] = self.joined.to_alipay_dict()
            else:
                params['joined'] = self.joined
        if self.marked:
            if hasattr(self.marked, 'to_alipay_dict'):
                params['marked'] = self.marked.to_alipay_dict()
            else:
                params['marked'] = self.marked
        if self.quest_id:
            if hasattr(self.quest_id, 'to_alipay_dict'):
                params['quest_id'] = self.quest_id.to_alipay_dict()
            else:
                params['quest_id'] = self.quest_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QuestInstanceDTO()
        if 'action_schema' in d:
            o.action_schema = d['action_schema']
        if 'day_count' in d:
            o.day_count = d['day_count']
        if 'icon' in d:
            o.icon = d['icon']
        if 'instance_id' in d:
            o.instance_id = d['instance_id']
        if 'join_count' in d:
            o.join_count = d['join_count']
        if 'joined' in d:
            o.joined = d['joined']
        if 'marked' in d:
            o.marked = d['marked']
        if 'quest_id' in d:
            o.quest_id = d['quest_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.VoucherBillDetail import VoucherBillDetail


class AlipayMarketingVoucherQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherQueryResponse, self).__init__()
        self._available_amount = None
        self._bill_details = None
        self._extend_info = None
        self._gmt_active = None
        self._gmt_create = None
        self._gmt_expired = None
        self._name = None
        self._status = None
        self._template_id = None
        self._total_amount = None
        self._user_id = None
        self._voucher_id = None

    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def bill_details(self):
        return self._bill_details

    @bill_details.setter
    def bill_details(self, value):
        if isinstance(value, list):
            self._bill_details = list()
            for i in value:
                if isinstance(i, VoucherBillDetail):
                    self._bill_details.append(i)
                else:
                    self._bill_details.append(VoucherBillDetail.from_alipay_dict(i))
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def gmt_active(self):
        return self._gmt_active

    @gmt_active.setter
    def gmt_active(self, value):
        self._gmt_active = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_expired(self):
        return self._gmt_expired

    @gmt_expired.setter
    def gmt_expired(self, value):
        self._gmt_expired = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherQueryResponse, self).parse_response_content(response_content)
        if 'available_amount' in response:
            self.available_amount = response['available_amount']
        if 'bill_details' in response:
            self.bill_details = response['bill_details']
        if 'extend_info' in response:
            self.extend_info = response['extend_info']
        if 'gmt_active' in response:
            self.gmt_active = response['gmt_active']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_expired' in response:
            self.gmt_expired = response['gmt_expired']
        if 'name' in response:
            self.name = response['name']
        if 'status' in response:
            self.status = response['status']
        if 'template_id' in response:
            self.template_id = response['template_id']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'user_id' in response:
            self.user_id = response['user_id']
        if 'voucher_id' in response:
            self.voucher_id = response['voucher_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MemberCardTemplateConfig import MemberCardTemplateConfig
from alipay.aop.api.domain.MemberCardOperator import MemberCardOperator
from alipay.aop.api.domain.MemberCardPayEffectiveRule import MemberCardPayEffectiveRule
from alipay.aop.api.domain.MemberCardCreatePrepaidPromotionPlanInfo import MemberCardCreatePrepaidPromotionPlanInfo


class AntMerchantExpandMembercardConfigModifyModel(object):

    def __init__(self):
        self._card_template_config = None
        self._member_product_id = None
        self._operator = None
        self._out_biz_no = None
        self._pay_effective_rule = None
        self._prepaid_promotion_plans = None

    @property
    def card_template_config(self):
        return self._card_template_config

    @card_template_config.setter
    def card_template_config(self, value):
        if isinstance(value, MemberCardTemplateConfig):
            self._card_template_config = value
        else:
            self._card_template_config = MemberCardTemplateConfig.from_alipay_dict(value)
    @property
    def member_product_id(self):
        return self._member_product_id

    @member_product_id.setter
    def member_product_id(self, value):
        self._member_product_id = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        if isinstance(value, MemberCardOperator):
            self._operator = value
        else:
            self._operator = MemberCardOperator.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pay_effective_rule(self):
        return self._pay_effective_rule

    @pay_effective_rule.setter
    def pay_effective_rule(self, value):
        if isinstance(value, MemberCardPayEffectiveRule):
            self._pay_effective_rule = value
        else:
            self._pay_effective_rule = MemberCardPayEffectiveRule.from_alipay_dict(value)
    @property
    def prepaid_promotion_plans(self):
        return self._prepaid_promotion_plans

    @prepaid_promotion_plans.setter
    def prepaid_promotion_plans(self, value):
        if isinstance(value, list):
            self._prepaid_promotion_plans = list()
            for i in value:
                if isinstance(i, MemberCardCreatePrepaidPromotionPlanInfo):
                    self._prepaid_promotion_plans.append(i)
                else:
                    self._prepaid_promotion_plans.append(MemberCardCreatePrepaidPromotionPlanInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.card_template_config:
            if hasattr(self.card_template_config, 'to_alipay_dict'):
                params['card_template_config'] = self.card_template_config.to_alipay_dict()
            else:
                params['card_template_config'] = self.card_template_config
        if self.member_product_id:
            if hasattr(self.member_product_id, 'to_alipay_dict'):
                params['member_product_id'] = self.member_product_id.to_alipay_dict()
            else:
                params['member_product_id'] = self.member_product_id
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.pay_effective_rule:
            if hasattr(self.pay_effective_rule, 'to_alipay_dict'):
                params['pay_effective_rule'] = self.pay_effective_rule.to_alipay_dict()
            else:
                params['pay_effective_rule'] = self.pay_effective_rule
        if self.prepaid_promotion_plans:
            if isinstance(self.prepaid_promotion_plans, list):
                for i in range(0, len(self.prepaid_promotion_plans)):
                    element = self.prepaid_promotion_plans[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prepaid_promotion_plans[i] = element.to_alipay_dict()
            if hasattr(self.prepaid_promotion_plans, 'to_alipay_dict'):
                params['prepaid_promotion_plans'] = self.prepaid_promotion_plans.to_alipay_dict()
            else:
                params['prepaid_promotion_plans'] = self.prepaid_promotion_plans
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandMembercardConfigModifyModel()
        if 'card_template_config' in d:
            o.card_template_config = d['card_template_config']
        if 'member_product_id' in d:
            o.member_product_id = d['member_product_id']
        if 'operator' in d:
            o.operator = d['operator']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'pay_effective_rule' in d:
            o.pay_effective_rule = d['pay_effective_rule']
        if 'prepaid_promotion_plans' in d:
            o.prepaid_promotion_plans = d['prepaid_promotion_plans']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommerceMedicalBankcardCertificationQueryData(object):

    def __init__(self):
        self._gmt_response = None
        self._is_bankcard_certified = None

    @property
    def gmt_response(self):
        return self._gmt_response

    @gmt_response.setter
    def gmt_response(self, value):
        self._gmt_response = value
    @property
    def is_bankcard_certified(self):
        return self._is_bankcard_certified

    @is_bankcard_certified.setter
    def is_bankcard_certified(self, value):
        self._is_bankcard_certified = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_response:
            if hasattr(self.gmt_response, 'to_alipay_dict'):
                params['gmt_response'] = self.gmt_response.to_alipay_dict()
            else:
                params['gmt_response'] = self.gmt_response
        if self.is_bankcard_certified:
            if hasattr(self.is_bankcard_certified, 'to_alipay_dict'):
                params['is_bankcard_certified'] = self.is_bankcard_certified.to_alipay_dict()
            else:
                params['is_bankcard_certified'] = self.is_bankcard_certified
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommerceMedicalBankcardCertificationQueryData()
        if 'gmt_response' in d:
            o.gmt_response = d['gmt_response']
        if 'is_bankcard_certified' in d:
            o.is_bankcard_certified = d['is_bankcard_certified']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItemOrderOpenData import ItemOrderOpenData


class AntMerchantExpandTradeorderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandTradeorderQueryResponse, self).__init__()
        self._amount = None
        self._biz_seq = None
        self._buyer_id = None
        self._ext_info = None
        self._gmt_create = None
        self._gmt_modified = None
        self._gmt_paid = None
        self._item_orders = None
        self._logistics_status = None
        self._memo = None
        self._merchant_subsidy_amount = None
        self._order_id = None
        self._out_biz_no = None
        self._out_biz_type = None
        self._partner_id = None
        self._partner_subsidy_amount = None
        self._real_amount = None
        self._seller_id = None
        self._shop_id = None
        self._status = None
        self._trade_no = None
        self._type = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_seq(self):
        return self._biz_seq

    @biz_seq.setter
    def biz_seq(self, value):
        self._biz_seq = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def gmt_paid(self):
        return self._gmt_paid

    @gmt_paid.setter
    def gmt_paid(self, value):
        self._gmt_paid = value
    @property
    def item_orders(self):
        return self._item_orders

    @item_orders.setter
    def item_orders(self, value):
        if isinstance(value, list):
            self._item_orders = list()
            for i in value:
                if isinstance(i, ItemOrderOpenData):
                    self._item_orders.append(i)
                else:
                    self._item_orders.append(ItemOrderOpenData.from_alipay_dict(i))
    @property
    def logistics_status(self):
        return self._logistics_status

    @logistics_status.setter
    def logistics_status(self, value):
        self._logistics_status = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_subsidy_amount(self):
        return self._merchant_subsidy_amount

    @merchant_subsidy_amount.setter
    def merchant_subsidy_amount(self, value):
        self._merchant_subsidy_amount = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def partner_subsidy_amount(self):
        return self._partner_subsidy_amount

    @partner_subsidy_amount.setter
    def partner_subsidy_amount(self, value):
        self._partner_subsidy_amount = value
    @property
    def real_amount(self):
        return self._real_amount

    @real_amount.setter
    def real_amount(self, value):
        self._real_amount = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandTradeorderQueryResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'biz_seq' in response:
            self.biz_seq = response['biz_seq']
        if 'buyer_id' in response:
            self.buyer_id = response['buyer_id']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_modified' in response:
            self.gmt_modified = response['gmt_modified']
        if 'gmt_paid' in response:
            self.gmt_paid = response['gmt_paid']
        if 'item_orders' in response:
            self.item_orders = response['item_orders']
        if 'logistics_status' in response:
            self.logistics_status = response['logistics_status']
        if 'memo' in response:
            self.memo = response['memo']
        if 'merchant_subsidy_amount' in response:
            self.merchant_subsidy_amount = response['merchant_subsidy_amount']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'out_biz_type' in response:
            self.out_biz_type = response['out_biz_type']
        if 'partner_id' in response:
            self.partner_id = response['partner_id']
        if 'partner_subsidy_amount' in response:
            self.partner_subsidy_amount = response['partner_subsidy_amount']
        if 'real_amount' in response:
            self.real_amount = response['real_amount']
        if 'seller_id' in response:
            self.seller_id = response['seller_id']
        if 'shop_id' in response:
            self.shop_id = response['shop_id']
        if 'status' in response:
            self.status = response['status']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'type' in response:
            self.type = response['type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserLoginStatusDetail(object):

    def __init__(self):
        self._contact_email = None
        self._contact_name = None
        self._contact_phone = None
        self._user_id = None
        self._user_name = None
        self._user_show_name = None

    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def contact_phone(self):
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, value):
        self._contact_phone = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value
    @property
    def user_show_name(self):
        return self._user_show_name

    @user_show_name.setter
    def user_show_name(self, value):
        self._user_show_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.contact_email:
            if hasattr(self.contact_email, 'to_alipay_dict'):
                params['contact_email'] = self.contact_email.to_alipay_dict()
            else:
                params['contact_email'] = self.contact_email
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.contact_phone:
            if hasattr(self.contact_phone, 'to_alipay_dict'):
                params['contact_phone'] = self.contact_phone.to_alipay_dict()
            else:
                params['contact_phone'] = self.contact_phone
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        if self.user_show_name:
            if hasattr(self.user_show_name, 'to_alipay_dict'):
                params['user_show_name'] = self.user_show_name.to_alipay_dict()
            else:
                params['user_show_name'] = self.user_show_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserLoginStatusDetail()
        if 'contact_email' in d:
            o.contact_email = d['contact_email']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'contact_phone' in d:
            o.contact_phone = d['contact_phone']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_name' in d:
            o.user_name = d['user_name']
        if 'user_show_name' in d:
            o.user_show_name = d['user_show_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingCampaignRetailDmSetModel(object):

    def __init__(self):
        self._campaign_end_time = None
        self._content_id = None
        self._operate_type = None

    @property
    def campaign_end_time(self):
        return self._campaign_end_time

    @campaign_end_time.setter
    def campaign_end_time(self, value):
        self._campaign_end_time = value
    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.campaign_end_time:
            if hasattr(self.campaign_end_time, 'to_alipay_dict'):
                params['campaign_end_time'] = self.campaign_end_time.to_alipay_dict()
            else:
                params['campaign_end_time'] = self.campaign_end_time
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignRetailDmSetModel()
        if 'campaign_end_time' in d:
            o.campaign_end_time = d['campaign_end_time']
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PaidOuterCardCycleInfoDTO(object):

    def __init__(self):
        self._alipay_deduct_agreement = None
        self._alipay_deduct_product_code = None
        self._alipay_deduct_scene = None
        self._close_reason = None
        self._cycle_type = None
        self._open_status = None

    @property
    def alipay_deduct_agreement(self):
        return self._alipay_deduct_agreement

    @alipay_deduct_agreement.setter
    def alipay_deduct_agreement(self, value):
        self._alipay_deduct_agreement = value
    @property
    def alipay_deduct_product_code(self):
        return self._alipay_deduct_product_code

    @alipay_deduct_product_code.setter
    def alipay_deduct_product_code(self, value):
        self._alipay_deduct_product_code = value
    @property
    def alipay_deduct_scene(self):
        return self._alipay_deduct_scene

    @alipay_deduct_scene.setter
    def alipay_deduct_scene(self, value):
        self._alipay_deduct_scene = value
    @property
    def close_reason(self):
        return self._close_reason

    @close_reason.setter
    def close_reason(self, value):
        self._close_reason = value
    @property
    def cycle_type(self):
        return self._cycle_type

    @cycle_type.setter
    def cycle_type(self, value):
        self._cycle_type = value
    @property
    def open_status(self):
        return self._open_status

    @open_status.setter
    def open_status(self, value):
        self._open_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_deduct_agreement:
            if hasattr(self.alipay_deduct_agreement, 'to_alipay_dict'):
                params['alipay_deduct_agreement'] = self.alipay_deduct_agreement.to_alipay_dict()
            else:
                params['alipay_deduct_agreement'] = self.alipay_deduct_agreement
        if self.alipay_deduct_product_code:
            if hasattr(self.alipay_deduct_product_code, 'to_alipay_dict'):
                params['alipay_deduct_product_code'] = self.alipay_deduct_product_code.to_alipay_dict()
            else:
                params['alipay_deduct_product_code'] = self.alipay_deduct_product_code
        if self.alipay_deduct_scene:
            if hasattr(self.alipay_deduct_scene, 'to_alipay_dict'):
                params['alipay_deduct_scene'] = self.alipay_deduct_scene.to_alipay_dict()
            else:
                params['alipay_deduct_scene'] = self.alipay_deduct_scene
        if self.close_reason:
            if hasattr(self.close_reason, 'to_alipay_dict'):
                params['close_reason'] = self.close_reason.to_alipay_dict()
            else:
                params['close_reason'] = self.close_reason
        if self.cycle_type:
            if hasattr(self.cycle_type, 'to_alipay_dict'):
                params['cycle_type'] = self.cycle_type.to_alipay_dict()
            else:
                params['cycle_type'] = self.cycle_type
        if self.open_status:
            if hasattr(self.open_status, 'to_alipay_dict'):
                params['open_status'] = self.open_status.to_alipay_dict()
            else:
                params['open_status'] = self.open_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaidOuterCardCycleInfoDTO()
        if 'alipay_deduct_agreement' in d:
            o.alipay_deduct_agreement = d['alipay_deduct_agreement']
        if 'alipay_deduct_product_code' in d:
            o.alipay_deduct_product_code = d['alipay_deduct_product_code']
        if 'alipay_deduct_scene' in d:
            o.alipay_deduct_scene = d['alipay_deduct_scene']
        if 'close_reason' in d:
            o.close_reason = d['close_reason']
        if 'cycle_type' in d:
            o.cycle_type = d['cycle_type']
        if 'open_status' in d:
            o.open_status = d['open_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EventInfo(object):

    def __init__(self):
        self._apdid_token = None
        self._cert_no = None
        self._cert_type = None
        self._email = None
        self._event_code = None
        self._gmt_occur = None
        self._mobile = None
        self._order_id = None
        self._platform = None
        self._user_name = None

    @property
    def apdid_token(self):
        return self._apdid_token

    @apdid_token.setter
    def apdid_token(self, value):
        self._apdid_token = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def event_code(self):
        return self._event_code

    @event_code.setter
    def event_code(self, value):
        self._event_code = value
    @property
    def gmt_occur(self):
        return self._gmt_occur

    @gmt_occur.setter
    def gmt_occur(self, value):
        self._gmt_occur = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.apdid_token:
            if hasattr(self.apdid_token, 'to_alipay_dict'):
                params['apdid_token'] = self.apdid_token.to_alipay_dict()
            else:
                params['apdid_token'] = self.apdid_token
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.event_code:
            if hasattr(self.event_code, 'to_alipay_dict'):
                params['event_code'] = self.event_code.to_alipay_dict()
            else:
                params['event_code'] = self.event_code
        if self.gmt_occur:
            if hasattr(self.gmt_occur, 'to_alipay_dict'):
                params['gmt_occur'] = self.gmt_occur.to_alipay_dict()
            else:
                params['gmt_occur'] = self.gmt_occur
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EventInfo()
        if 'apdid_token' in d:
            o.apdid_token = d['apdid_token']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'email' in d:
            o.email = d['email']
        if 'event_code' in d:
            o.event_code = d['event_code']
        if 'gmt_occur' in d:
            o.gmt_occur = d['gmt_occur']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'platform' in d:
            o.platform = d['platform']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAccountNegativecardSendModel(object):

    def __init__(self):
        self._arguments = None
        self._ext_info = None
        self._service_code = None
        self._user_id = None

    @property
    def arguments(self):
        return self._arguments

    @arguments.setter
    def arguments(self, value):
        self._arguments = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.arguments:
            if hasattr(self.arguments, 'to_alipay_dict'):
                params['arguments'] = self.arguments.to_alipay_dict()
            else:
                params['arguments'] = self.arguments
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAccountNegativecardSendModel()
        if 'arguments' in d:
            o.arguments = d['arguments']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TradeRecord import TradeRecord


class AlipayUserTradeSearchResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserTradeSearchResponse, self).__init__()
        self._total_pages = None
        self._total_results = None
        self._trade_records = None

    @property
    def total_pages(self):
        return self._total_pages

    @total_pages.setter
    def total_pages(self, value):
        self._total_pages = value
    @property
    def total_results(self):
        return self._total_results

    @total_results.setter
    def total_results(self, value):
        self._total_results = value
    @property
    def trade_records(self):
        return self._trade_records

    @trade_records.setter
    def trade_records(self, value):
        if isinstance(value, list):
            self._trade_records = list()
            for i in value:
                if isinstance(i, TradeRecord):
                    self._trade_records.append(i)
                else:
                    self._trade_records.append(TradeRecord.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayUserTradeSearchResponse, self).parse_response_content(response_content)
        if 'total_pages' in response:
            self.total_pages = response['total_pages']
        if 'total_results' in response:
            self.total_results = response['total_results']
        if 'trade_records' in response:
            self.trade_records = response['trade_records']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOfflineMaterialImageUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOfflineMaterialImageUploadResponse, self).__init__()
        self._image_id = None
        self._image_url = None

    @property
    def image_id(self):
        return self._image_id

    @image_id.setter
    def image_id(self, value):
        self._image_id = value
    @property
    def image_url(self):
        return self._image_url

    @image_url.setter
    def image_url(self, value):
        self._image_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayOfflineMaterialImageUploadResponse, self).parse_response_content(response_content)
        if 'image_id' in response:
            self.image_id = response['image_id']
        if 'image_url' in response:
            self.image_url = response['image_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiTradePosDataSyncModel(object):

    def __init__(self):
        self._biz_code = None
        self._content = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiTradePosDataSyncModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'content' in d:
            o.content = d['content']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportVehicleownerBlacklistSyncModel(object):

    def __init__(self):
        self._agreement_no = None
        self._plate_color = None
        self._plate_no = None
        self._source = None
        self._status_opt = None
        self._status_opt_time = None
        self._status_reason = None
        self._status_reason_code = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def status_opt(self):
        return self._status_opt

    @status_opt.setter
    def status_opt(self, value):
        self._status_opt = value
    @property
    def status_opt_time(self):
        return self._status_opt_time

    @status_opt_time.setter
    def status_opt_time(self, value):
        self._status_opt_time = value
    @property
    def status_reason(self):
        return self._status_reason

    @status_reason.setter
    def status_reason(self, value):
        self._status_reason = value
    @property
    def status_reason_code(self):
        return self._status_reason_code

    @status_reason_code.setter
    def status_reason_code(self, value):
        self._status_reason_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.status_opt:
            if hasattr(self.status_opt, 'to_alipay_dict'):
                params['status_opt'] = self.status_opt.to_alipay_dict()
            else:
                params['status_opt'] = self.status_opt
        if self.status_opt_time:
            if hasattr(self.status_opt_time, 'to_alipay_dict'):
                params['status_opt_time'] = self.status_opt_time.to_alipay_dict()
            else:
                params['status_opt_time'] = self.status_opt_time
        if self.status_reason:
            if hasattr(self.status_reason, 'to_alipay_dict'):
                params['status_reason'] = self.status_reason.to_alipay_dict()
            else:
                params['status_reason'] = self.status_reason
        if self.status_reason_code:
            if hasattr(self.status_reason_code, 'to_alipay_dict'):
                params['status_reason_code'] = self.status_reason_code.to_alipay_dict()
            else:
                params['status_reason_code'] = self.status_reason_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportVehicleownerBlacklistSyncModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'source' in d:
            o.source = d['source']
        if 'status_opt' in d:
            o.status_opt = d['status_opt']
        if 'status_opt_time' in d:
            o.status_opt_time = d['status_opt_time']
        if 'status_reason' in d:
            o.status_reason = d['status_reason']
        if 'status_reason_code' in d:
            o.status_reason_code = d['status_reason_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.UserAdvanceInfo import UserAdvanceInfo


class AlipayEcoMycarParkingAgreementQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarParkingAgreementQueryResponse, self).__init__()
        self._advance_status = None
        self._agreement_scene = None
        self._agreement_status = None
        self._car_status = None
        self._current_time = None
        self._expire_time = None
        self._user_advance_info = None

    @property
    def advance_status(self):
        return self._advance_status

    @advance_status.setter
    def advance_status(self, value):
        self._advance_status = value
    @property
    def agreement_scene(self):
        return self._agreement_scene

    @agreement_scene.setter
    def agreement_scene(self, value):
        self._agreement_scene = value
    @property
    def agreement_status(self):
        return self._agreement_status

    @agreement_status.setter
    def agreement_status(self, value):
        self._agreement_status = value
    @property
    def car_status(self):
        return self._car_status

    @car_status.setter
    def car_status(self, value):
        self._car_status = value
    @property
    def current_time(self):
        return self._current_time

    @current_time.setter
    def current_time(self, value):
        self._current_time = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def user_advance_info(self):
        return self._user_advance_info

    @user_advance_info.setter
    def user_advance_info(self, value):
        if isinstance(value, UserAdvanceInfo):
            self._user_advance_info = value
        else:
            self._user_advance_info = UserAdvanceInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarParkingAgreementQueryResponse, self).parse_response_content(response_content)
        if 'advance_status' in response:
            self.advance_status = response['advance_status']
        if 'agreement_scene' in response:
            self.agreement_scene = response['agreement_scene']
        if 'agreement_status' in response:
            self.agreement_status = response['agreement_status']
        if 'car_status' in response:
            self.car_status = response['car_status']
        if 'current_time' in response:
            self.current_time = response['current_time']
        if 'expire_time' in response:
            self.expire_time = response['expire_time']
        if 'user_advance_info' in response:
            self.user_advance_info = response['user_advance_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoantradeLoanarrangementQueryModel(object):

    def __init__(self):
        self._ip_role_id = None
        self._loan_ar_no = None

    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def loan_ar_no(self):
        return self._loan_ar_no

    @loan_ar_no.setter
    def loan_ar_no(self, value):
        self._loan_ar_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.loan_ar_no:
            if hasattr(self.loan_ar_no, 'to_alipay_dict'):
                params['loan_ar_no'] = self.loan_ar_no.to_alipay_dict()
            else:
                params['loan_ar_no'] = self.loan_ar_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeLoanarrangementQueryModel()
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'loan_ar_no' in d:
            o.loan_ar_no = d['loan_ar_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeliveryAgencyMerchantInfo(object):

    def __init__(self):
        self._business_type = None
        self._merchant_id = None
        self._merchant_id_type = None

    @property
    def business_type(self):
        return self._business_type

    @business_type.setter
    def business_type(self, value):
        self._business_type = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def merchant_id_type(self):
        return self._merchant_id_type

    @merchant_id_type.setter
    def merchant_id_type(self, value):
        self._merchant_id_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_type:
            if hasattr(self.business_type, 'to_alipay_dict'):
                params['business_type'] = self.business_type.to_alipay_dict()
            else:
                params['business_type'] = self.business_type
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.merchant_id_type:
            if hasattr(self.merchant_id_type, 'to_alipay_dict'):
                params['merchant_id_type'] = self.merchant_id_type.to_alipay_dict()
            else:
                params['merchant_id_type'] = self.merchant_id_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliveryAgencyMerchantInfo()
        if 'business_type' in d:
            o.business_type = d['business_type']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'merchant_id_type' in d:
            o.merchant_id_type = d['merchant_id_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreditFreezeSubOrder import CreditFreezeSubOrder


class ZhimaCreditPeUserCreditFreezeModel(object):

    def __init__(self):
        self._buyer_id = None
        self._category_code = None
        self._credit_scene = None
        self._ext_info = None
        self._out_order_no = None
        self._out_request_no = None
        self._risk_info = None
        self._seller_id = None
        self._sub_order_info = None
        self._total_credit_amount = None

    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def credit_scene(self):
        return self._credit_scene

    @credit_scene.setter
    def credit_scene(self, value):
        self._credit_scene = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def risk_info(self):
        return self._risk_info

    @risk_info.setter
    def risk_info(self, value):
        self._risk_info = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def sub_order_info(self):
        return self._sub_order_info

    @sub_order_info.setter
    def sub_order_info(self, value):
        if isinstance(value, list):
            self._sub_order_info = list()
            for i in value:
                if isinstance(i, CreditFreezeSubOrder):
                    self._sub_order_info.append(i)
                else:
                    self._sub_order_info.append(CreditFreezeSubOrder.from_alipay_dict(i))
    @property
    def total_credit_amount(self):
        return self._total_credit_amount

    @total_credit_amount.setter
    def total_credit_amount(self, value):
        self._total_credit_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.credit_scene:
            if hasattr(self.credit_scene, 'to_alipay_dict'):
                params['credit_scene'] = self.credit_scene.to_alipay_dict()
            else:
                params['credit_scene'] = self.credit_scene
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.risk_info:
            if hasattr(self.risk_info, 'to_alipay_dict'):
                params['risk_info'] = self.risk_info.to_alipay_dict()
            else:
                params['risk_info'] = self.risk_info
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.sub_order_info:
            if isinstance(self.sub_order_info, list):
                for i in range(0, len(self.sub_order_info)):
                    element = self.sub_order_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_order_info[i] = element.to_alipay_dict()
            if hasattr(self.sub_order_info, 'to_alipay_dict'):
                params['sub_order_info'] = self.sub_order_info.to_alipay_dict()
            else:
                params['sub_order_info'] = self.sub_order_info
        if self.total_credit_amount:
            if hasattr(self.total_credit_amount, 'to_alipay_dict'):
                params['total_credit_amount'] = self.total_credit_amount.to_alipay_dict()
            else:
                params['total_credit_amount'] = self.total_credit_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeUserCreditFreezeModel()
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'credit_scene' in d:
            o.credit_scene = d['credit_scene']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'risk_info' in d:
            o.risk_info = d['risk_info']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'sub_order_info' in d:
            o.sub_order_info = d['sub_order_info']
        if 'total_credit_amount' in d:
            o.total_credit_amount = d['total_credit_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DriverTradeInfo(object):

    def __init__(self):
        self._create_date = None
        self._driver_user_id = None
        self._trade_no = None
        self._trade_total_amount = None

    @property
    def create_date(self):
        return self._create_date

    @create_date.setter
    def create_date(self, value):
        self._create_date = value
    @property
    def driver_user_id(self):
        return self._driver_user_id

    @driver_user_id.setter
    def driver_user_id(self, value):
        self._driver_user_id = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_total_amount(self):
        return self._trade_total_amount

    @trade_total_amount.setter
    def trade_total_amount(self, value):
        self._trade_total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_date:
            if hasattr(self.create_date, 'to_alipay_dict'):
                params['create_date'] = self.create_date.to_alipay_dict()
            else:
                params['create_date'] = self.create_date
        if self.driver_user_id:
            if hasattr(self.driver_user_id, 'to_alipay_dict'):
                params['driver_user_id'] = self.driver_user_id.to_alipay_dict()
            else:
                params['driver_user_id'] = self.driver_user_id
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_total_amount:
            if hasattr(self.trade_total_amount, 'to_alipay_dict'):
                params['trade_total_amount'] = self.trade_total_amount.to_alipay_dict()
            else:
                params['trade_total_amount'] = self.trade_total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DriverTradeInfo()
        if 'create_date' in d:
            o.create_date = d['create_date']
        if 'driver_user_id' in d:
            o.driver_user_id = d['driver_user_id']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_total_amount' in d:
            o.trade_total_amount = d['trade_total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SceneProdPaymentAccountInfo(object):

    def __init__(self):
        self._account_ext_no = None
        self._account_fip_code = None
        self._account_fip_name = None
        self._account_no = None
        self._account_type = None
        self._amt = None
        self._bank_card_category = None
        self._card_holder_name = None
        self._ext_card_type = None
        self._ext_info = None
        self._inst_out_code = None
        self._ip_id = None
        self._ip_role_id = None
        self._payment_mark = None

    @property
    def account_ext_no(self):
        return self._account_ext_no

    @account_ext_no.setter
    def account_ext_no(self, value):
        self._account_ext_no = value
    @property
    def account_fip_code(self):
        return self._account_fip_code

    @account_fip_code.setter
    def account_fip_code(self, value):
        self._account_fip_code = value
    @property
    def account_fip_name(self):
        return self._account_fip_name

    @account_fip_name.setter
    def account_fip_name(self, value):
        self._account_fip_name = value
    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def amt(self):
        return self._amt

    @amt.setter
    def amt(self, value):
        self._amt = value
    @property
    def bank_card_category(self):
        return self._bank_card_category

    @bank_card_category.setter
    def bank_card_category(self, value):
        self._bank_card_category = value
    @property
    def card_holder_name(self):
        return self._card_holder_name

    @card_holder_name.setter
    def card_holder_name(self, value):
        self._card_holder_name = value
    @property
    def ext_card_type(self):
        return self._ext_card_type

    @ext_card_type.setter
    def ext_card_type(self, value):
        self._ext_card_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def inst_out_code(self):
        return self._inst_out_code

    @inst_out_code.setter
    def inst_out_code(self, value):
        self._inst_out_code = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def payment_mark(self):
        return self._payment_mark

    @payment_mark.setter
    def payment_mark(self, value):
        self._payment_mark = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_ext_no:
            if hasattr(self.account_ext_no, 'to_alipay_dict'):
                params['account_ext_no'] = self.account_ext_no.to_alipay_dict()
            else:
                params['account_ext_no'] = self.account_ext_no
        if self.account_fip_code:
            if hasattr(self.account_fip_code, 'to_alipay_dict'):
                params['account_fip_code'] = self.account_fip_code.to_alipay_dict()
            else:
                params['account_fip_code'] = self.account_fip_code
        if self.account_fip_name:
            if hasattr(self.account_fip_name, 'to_alipay_dict'):
                params['account_fip_name'] = self.account_fip_name.to_alipay_dict()
            else:
                params['account_fip_name'] = self.account_fip_name
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.amt:
            if hasattr(self.amt, 'to_alipay_dict'):
                params['amt'] = self.amt.to_alipay_dict()
            else:
                params['amt'] = self.amt
        if self.bank_card_category:
            if hasattr(self.bank_card_category, 'to_alipay_dict'):
                params['bank_card_category'] = self.bank_card_category.to_alipay_dict()
            else:
                params['bank_card_category'] = self.bank_card_category
        if self.card_holder_name:
            if hasattr(self.card_holder_name, 'to_alipay_dict'):
                params['card_holder_name'] = self.card_holder_name.to_alipay_dict()
            else:
                params['card_holder_name'] = self.card_holder_name
        if self.ext_card_type:
            if hasattr(self.ext_card_type, 'to_alipay_dict'):
                params['ext_card_type'] = self.ext_card_type.to_alipay_dict()
            else:
                params['ext_card_type'] = self.ext_card_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.inst_out_code:
            if hasattr(self.inst_out_code, 'to_alipay_dict'):
                params['inst_out_code'] = self.inst_out_code.to_alipay_dict()
            else:
                params['inst_out_code'] = self.inst_out_code
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.payment_mark:
            if hasattr(self.payment_mark, 'to_alipay_dict'):
                params['payment_mark'] = self.payment_mark.to_alipay_dict()
            else:
                params['payment_mark'] = self.payment_mark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SceneProdPaymentAccountInfo()
        if 'account_ext_no' in d:
            o.account_ext_no = d['account_ext_no']
        if 'account_fip_code' in d:
            o.account_fip_code = d['account_fip_code']
        if 'account_fip_name' in d:
            o.account_fip_name = d['account_fip_name']
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'amt' in d:
            o.amt = d['amt']
        if 'bank_card_category' in d:
            o.bank_card_category = d['bank_card_category']
        if 'card_holder_name' in d:
            o.card_holder_name = d['card_holder_name']
        if 'ext_card_type' in d:
            o.ext_card_type = d['ext_card_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'inst_out_code' in d:
            o.inst_out_code = d['inst_out_code']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'payment_mark' in d:
            o.payment_mark = d['payment_mark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TimeCardConsumeCardInfo(object):

    def __init__(self):
        self._card_id = None
        self._desc = None
        self._item_id = None
        self._logo = None
        self._status = None
        self._title = None
        self._user_id = None

    @property
    def card_id(self):
        return self._card_id

    @card_id.setter
    def card_id(self, value):
        self._card_id = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_id:
            if hasattr(self.card_id, 'to_alipay_dict'):
                params['card_id'] = self.card_id.to_alipay_dict()
            else:
                params['card_id'] = self.card_id
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TimeCardConsumeCardInfo()
        if 'card_id' in d:
            o.card_id = d['card_id']
        if 'desc' in d:
            o.desc = d['desc']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'logo' in d:
            o.logo = d['logo']
        if 'status' in d:
            o.status = d['status']
        if 'title' in d:
            o.title = d['title']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo
from alipay.aop.api.domain.PaymentInformation import PaymentInformation


class AlipayMerchantOrderRefundModel(object):

    def __init__(self):
        self._biz_scene = None
        self._buyer = None
        self._ext_info = None
        self._order_id = None
        self._out_biz_no = None
        self._refund_reason = None
        self._refund_request = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, UserIdentity):
            self._buyer = value
        else:
            self._buyer = UserIdentity.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def refund_reason(self):
        return self._refund_reason

    @refund_reason.setter
    def refund_reason(self, value):
        self._refund_reason = value
    @property
    def refund_request(self):
        return self._refund_request

    @refund_request.setter
    def refund_request(self, value):
        if isinstance(value, list):
            self._refund_request = list()
            for i in value:
                if isinstance(i, PaymentInformation):
                    self._refund_request.append(i)
                else:
                    self._refund_request.append(PaymentInformation.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.buyer:
            if hasattr(self.buyer, 'to_alipay_dict'):
                params['buyer'] = self.buyer.to_alipay_dict()
            else:
                params['buyer'] = self.buyer
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.refund_reason:
            if hasattr(self.refund_reason, 'to_alipay_dict'):
                params['refund_reason'] = self.refund_reason.to_alipay_dict()
            else:
                params['refund_reason'] = self.refund_reason
        if self.refund_request:
            if isinstance(self.refund_request, list):
                for i in range(0, len(self.refund_request)):
                    element = self.refund_request[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.refund_request[i] = element.to_alipay_dict()
            if hasattr(self.refund_request, 'to_alipay_dict'):
                params['refund_request'] = self.refund_request.to_alipay_dict()
            else:
                params['refund_request'] = self.refund_request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantOrderRefundModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'buyer' in d:
            o.buyer = d['buyer']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'refund_reason' in d:
            o.refund_reason = d['refund_reason']
        if 'refund_request' in d:
            o.refund_request = d['refund_request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandMembercardRefundSubmitResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandMembercardRefundSubmitResponse, self).__init__()
        self._refund_amount = None
        self._refund_fee = None

    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_fee(self):
        return self._refund_fee

    @refund_fee.setter
    def refund_fee(self, value):
        self._refund_fee = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandMembercardRefundSubmitResponse, self).parse_response_content(response_content)
        if 'refund_amount' in response:
            self.refund_amount = response['refund_amount']
        if 'refund_fee' in response:
            self.refund_fee = response['refund_fee']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CateInfoVO import CateInfoVO
from alipay.aop.api.domain.ItemInfoVO import ItemInfoVO
from alipay.aop.api.domain.CateInfoVO import CateInfoVO


class AlipayCommerceEducateTrainRecommendQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEducateTrainRecommendQueryResponse, self).__init__()
        self._default_first_cate = None
        self._has_more = None
        self._item_infos = None
        self._selected_first_cate = None

    @property
    def default_first_cate(self):
        return self._default_first_cate

    @default_first_cate.setter
    def default_first_cate(self, value):
        if isinstance(value, CateInfoVO):
            self._default_first_cate = value
        else:
            self._default_first_cate = CateInfoVO.from_alipay_dict(value)
    @property
    def has_more(self):
        return self._has_more

    @has_more.setter
    def has_more(self, value):
        self._has_more = value
    @property
    def item_infos(self):
        return self._item_infos

    @item_infos.setter
    def item_infos(self, value):
        if isinstance(value, list):
            self._item_infos = list()
            for i in value:
                if isinstance(i, ItemInfoVO):
                    self._item_infos.append(i)
                else:
                    self._item_infos.append(ItemInfoVO.from_alipay_dict(i))
    @property
    def selected_first_cate(self):
        return self._selected_first_cate

    @selected_first_cate.setter
    def selected_first_cate(self, value):
        if isinstance(value, CateInfoVO):
            self._selected_first_cate = value
        else:
            self._selected_first_cate = CateInfoVO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEducateTrainRecommendQueryResponse, self).parse_response_content(response_content)
        if 'default_first_cate' in response:
            self.default_first_cate = response['default_first_cate']
        if 'has_more' in response:
            self.has_more = response['has_more']
        if 'item_infos' in response:
            self.item_infos = response['item_infos']
        if 'selected_first_cate' in response:
            self.selected_first_cate = response['selected_first_cate']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsPerson import InsPerson


class AlipayInsMarketingSellerSignModel(object):

    def __init__(self):
        self._out_biz_no = None
        self._prod_code = None
        self._seller = None
        self._sign_alipay_id = None

    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, InsPerson):
            self._seller = value
        else:
            self._seller = InsPerson.from_alipay_dict(value)
    @property
    def sign_alipay_id(self):
        return self._sign_alipay_id

    @sign_alipay_id.setter
    def sign_alipay_id(self, value):
        self._sign_alipay_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.prod_code:
            if hasattr(self.prod_code, 'to_alipay_dict'):
                params['prod_code'] = self.prod_code.to_alipay_dict()
            else:
                params['prod_code'] = self.prod_code
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        if self.sign_alipay_id:
            if hasattr(self.sign_alipay_id, 'to_alipay_dict'):
                params['sign_alipay_id'] = self.sign_alipay_id.to_alipay_dict()
            else:
                params['sign_alipay_id'] = self.sign_alipay_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsMarketingSellerSignModel()
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'prod_code' in d:
            o.prod_code = d['prod_code']
        if 'seller' in d:
            o.seller = d['seller']
        if 'sign_alipay_id' in d:
            o.sign_alipay_id = d['sign_alipay_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSpOpporFeedbackModifyModel(object):

    def __init__(self):
        self._expand_result = None
        self._isv_pid = None
        self._leads_id = None
        self._merchant_pid = None
        self._oppor_id = None
        self._sn = None

    @property
    def expand_result(self):
        return self._expand_result

    @expand_result.setter
    def expand_result(self, value):
        self._expand_result = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def leads_id(self):
        return self._leads_id

    @leads_id.setter
    def leads_id(self, value):
        self._leads_id = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def oppor_id(self):
        return self._oppor_id

    @oppor_id.setter
    def oppor_id(self, value):
        self._oppor_id = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value


    def to_alipay_dict(self):
        params = dict()
        if self.expand_result:
            if hasattr(self.expand_result, 'to_alipay_dict'):
                params['expand_result'] = self.expand_result.to_alipay_dict()
            else:
                params['expand_result'] = self.expand_result
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.leads_id:
            if hasattr(self.leads_id, 'to_alipay_dict'):
                params['leads_id'] = self.leads_id.to_alipay_dict()
            else:
                params['leads_id'] = self.leads_id
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.oppor_id:
            if hasattr(self.oppor_id, 'to_alipay_dict'):
                params['oppor_id'] = self.oppor_id.to_alipay_dict()
            else:
                params['oppor_id'] = self.oppor_id
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSpOpporFeedbackModifyModel()
        if 'expand_result' in d:
            o.expand_result = d['expand_result']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'leads_id' in d:
            o.leads_id = d['leads_id']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'oppor_id' in d:
            o.oppor_id = d['oppor_id']
        if 'sn' in d:
            o.sn = d['sn']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainTwcUserMatchResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainTwcUserMatchResponse, self).__init__()
        self._desc = None
        self._match_success = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def match_success(self):
        return self._match_success

    @match_success.setter
    def match_success(self, value):
        self._match_success = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainTwcUserMatchResponse, self).parse_response_content(response_content)
        if 'desc' in response:
            self.desc = response['desc']
        if 'match_success' in response:
            self.match_success = response['match_success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.StandardVoucherOpenApiVO import StandardVoucherOpenApiVO


class AlipayBossFncGffundStandardvoucherBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossFncGffundStandardvoucherBatchqueryResponse, self).__init__()
        self._cur_page = None
        self._page_size = None
        self._standard_voucher_list = None
        self._success = None
        self._total_items = None
        self._total_pages = None

    @property
    def cur_page(self):
        return self._cur_page

    @cur_page.setter
    def cur_page(self, value):
        self._cur_page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def standard_voucher_list(self):
        return self._standard_voucher_list

    @standard_voucher_list.setter
    def standard_voucher_list(self, value):
        if isinstance(value, list):
            self._standard_voucher_list = list()
            for i in value:
                if isinstance(i, StandardVoucherOpenApiVO):
                    self._standard_voucher_list.append(i)
                else:
                    self._standard_voucher_list.append(StandardVoucherOpenApiVO.from_alipay_dict(i))
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def total_items(self):
        return self._total_items

    @total_items.setter
    def total_items(self, value):
        self._total_items = value
    @property
    def total_pages(self):
        return self._total_pages

    @total_pages.setter
    def total_pages(self, value):
        self._total_pages = value

    def parse_response_content(self, response_content):
        response = super(AlipayBossFncGffundStandardvoucherBatchqueryResponse, self).parse_response_content(response_content)
        if 'cur_page' in response:
            self.cur_page = response['cur_page']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'standard_voucher_list' in response:
            self.standard_voucher_list = response['standard_voucher_list']
        if 'success' in response:
            self.success = response['success']
        if 'total_items' in response:
            self.total_items = response['total_items']
        if 'total_pages' in response:
            self.total_pages = response['total_pages']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InvoiceItem import InvoiceItem


class AlipayEbppInvoiceApplyInvUploadModel(object):

    def __init__(self):
        self._anti_fake_code = None
        self._apply_id = None
        self._biz_error_code = None
        self._biz_error_msg = None
        self._business_type = None
        self._check_code = None
        self._create_result = None
        self._device_no = None
        self._invoice_amount = None
        self._invoice_code = None
        self._invoice_date = None
        self._invoice_file_content = None
        self._invoice_file_type = None
        self._invoice_items = None
        self._invoice_kind = None
        self._invoice_memo = None
        self._invoice_no = None
        self._invoice_type = None
        self._levy_type = None
        self._normal_invoice_code = None
        self._normal_invoice_no = None
        self._payee_address = None
        self._payee_bank_account_id = None
        self._payee_bank_name = None
        self._payee_checker = None
        self._payee_name = None
        self._payee_operator = None
        self._payee_phone = None
        self._payee_receiver = None
        self._payee_register_no = None
        self._payer_address = None
        self._payer_bank_account_id = None
        self._payer_bank_name = None
        self._payer_email = None
        self._payer_name = None
        self._payer_phone = None
        self._payer_register_no = None
        self._platform_code = None
        self._platform_tid = None
        self._platform_user_id = None
        self._qr_code = None
        self._receive_mobile = None
        self._red_notice_no = None
        self._serial_no = None
        self._source = None
        self._special_flag = None
        self._sum_price = None
        self._sum_tax = None

    @property
    def anti_fake_code(self):
        return self._anti_fake_code

    @anti_fake_code.setter
    def anti_fake_code(self, value):
        self._anti_fake_code = value
    @property
    def apply_id(self):
        return self._apply_id

    @apply_id.setter
    def apply_id(self, value):
        self._apply_id = value
    @property
    def biz_error_code(self):
        return self._biz_error_code

    @biz_error_code.setter
    def biz_error_code(self, value):
        self._biz_error_code = value
    @property
    def biz_error_msg(self):
        return self._biz_error_msg

    @biz_error_msg.setter
    def biz_error_msg(self, value):
        self._biz_error_msg = value
    @property
    def business_type(self):
        return self._business_type

    @business_type.setter
    def business_type(self, value):
        self._business_type = value
    @property
    def check_code(self):
        return self._check_code

    @check_code.setter
    def check_code(self, value):
        self._check_code = value
    @property
    def create_result(self):
        return self._create_result

    @create_result.setter
    def create_result(self, value):
        self._create_result = value
    @property
    def device_no(self):
        return self._device_no

    @device_no.setter
    def device_no(self, value):
        self._device_no = value
    @property
    def invoice_amount(self):
        return self._invoice_amount

    @invoice_amount.setter
    def invoice_amount(self, value):
        self._invoice_amount = value
    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_date(self):
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, value):
        self._invoice_date = value
    @property
    def invoice_file_content(self):
        return self._invoice_file_content

    @invoice_file_content.setter
    def invoice_file_content(self, value):
        self._invoice_file_content = value
    @property
    def invoice_file_type(self):
        return self._invoice_file_type

    @invoice_file_type.setter
    def invoice_file_type(self, value):
        self._invoice_file_type = value
    @property
    def invoice_items(self):
        return self._invoice_items

    @invoice_items.setter
    def invoice_items(self, value):
        if isinstance(value, InvoiceItem):
            self._invoice_items = value
        else:
            self._invoice_items = InvoiceItem.from_alipay_dict(value)
    @property
    def invoice_kind(self):
        return self._invoice_kind

    @invoice_kind.setter
    def invoice_kind(self, value):
        self._invoice_kind = value
    @property
    def invoice_memo(self):
        return self._invoice_memo

    @invoice_memo.setter
    def invoice_memo(self, value):
        self._invoice_memo = value
    @property
    def invoice_no(self):
        return self._invoice_no

    @invoice_no.setter
    def invoice_no(self, value):
        self._invoice_no = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def levy_type(self):
        return self._levy_type

    @levy_type.setter
    def levy_type(self, value):
        self._levy_type = value
    @property
    def normal_invoice_code(self):
        return self._normal_invoice_code

    @normal_invoice_code.setter
    def normal_invoice_code(self, value):
        self._normal_invoice_code = value
    @property
    def normal_invoice_no(self):
        return self._normal_invoice_no

    @normal_invoice_no.setter
    def normal_invoice_no(self, value):
        self._normal_invoice_no = value
    @property
    def payee_address(self):
        return self._payee_address

    @payee_address.setter
    def payee_address(self, value):
        self._payee_address = value
    @property
    def payee_bank_account_id(self):
        return self._payee_bank_account_id

    @payee_bank_account_id.setter
    def payee_bank_account_id(self, value):
        self._payee_bank_account_id = value
    @property
    def payee_bank_name(self):
        return self._payee_bank_name

    @payee_bank_name.setter
    def payee_bank_name(self, value):
        self._payee_bank_name = value
    @property
    def payee_checker(self):
        return self._payee_checker

    @payee_checker.setter
    def payee_checker(self, value):
        self._payee_checker = value
    @property
    def payee_name(self):
        return self._payee_name

    @payee_name.setter
    def payee_name(self, value):
        self._payee_name = value
    @property
    def payee_operator(self):
        return self._payee_operator

    @payee_operator.setter
    def payee_operator(self, value):
        self._payee_operator = value
    @property
    def payee_phone(self):
        return self._payee_phone

    @payee_phone.setter
    def payee_phone(self, value):
        self._payee_phone = value
    @property
    def payee_receiver(self):
        return self._payee_receiver

    @payee_receiver.setter
    def payee_receiver(self, value):
        self._payee_receiver = value
    @property
    def payee_register_no(self):
        return self._payee_register_no

    @payee_register_no.setter
    def payee_register_no(self, value):
        self._payee_register_no = value
    @property
    def payer_address(self):
        return self._payer_address

    @payer_address.setter
    def payer_address(self, value):
        self._payer_address = value
    @property
    def payer_bank_account_id(self):
        return self._payer_bank_account_id

    @payer_bank_account_id.setter
    def payer_bank_account_id(self, value):
        self._payer_bank_account_id = value
    @property
    def payer_bank_name(self):
        return self._payer_bank_name

    @payer_bank_name.setter
    def payer_bank_name(self, value):
        self._payer_bank_name = value
    @property
    def payer_email(self):
        return self._payer_email

    @payer_email.setter
    def payer_email(self, value):
        self._payer_email = value
    @property
    def payer_name(self):
        return self._payer_name

    @payer_name.setter
    def payer_name(self, value):
        self._payer_name = value
    @property
    def payer_phone(self):
        return self._payer_phone

    @payer_phone.setter
    def payer_phone(self, value):
        self._payer_phone = value
    @property
    def payer_register_no(self):
        return self._payer_register_no

    @payer_register_no.setter
    def payer_register_no(self, value):
        self._payer_register_no = value
    @property
    def platform_code(self):
        return self._platform_code

    @platform_code.setter
    def platform_code(self, value):
        self._platform_code = value
    @property
    def platform_tid(self):
        return self._platform_tid

    @platform_tid.setter
    def platform_tid(self, value):
        self._platform_tid = value
    @property
    def platform_user_id(self):
        return self._platform_user_id

    @platform_user_id.setter
    def platform_user_id(self, value):
        self._platform_user_id = value
    @property
    def qr_code(self):
        return self._qr_code

    @qr_code.setter
    def qr_code(self, value):
        self._qr_code = value
    @property
    def receive_mobile(self):
        return self._receive_mobile

    @receive_mobile.setter
    def receive_mobile(self, value):
        self._receive_mobile = value
    @property
    def red_notice_no(self):
        return self._red_notice_no

    @red_notice_no.setter
    def red_notice_no(self, value):
        self._red_notice_no = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def special_flag(self):
        return self._special_flag

    @special_flag.setter
    def special_flag(self, value):
        self._special_flag = value
    @property
    def sum_price(self):
        return self._sum_price

    @sum_price.setter
    def sum_price(self, value):
        self._sum_price = value
    @property
    def sum_tax(self):
        return self._sum_tax

    @sum_tax.setter
    def sum_tax(self, value):
        self._sum_tax = value


    def to_alipay_dict(self):
        params = dict()
        if self.anti_fake_code:
            if hasattr(self.anti_fake_code, 'to_alipay_dict'):
                params['anti_fake_code'] = self.anti_fake_code.to_alipay_dict()
            else:
                params['anti_fake_code'] = self.anti_fake_code
        if self.apply_id:
            if hasattr(self.apply_id, 'to_alipay_dict'):
                params['apply_id'] = self.apply_id.to_alipay_dict()
            else:
                params['apply_id'] = self.apply_id
        if self.biz_error_code:
            if hasattr(self.biz_error_code, 'to_alipay_dict'):
                params['biz_error_code'] = self.biz_error_code.to_alipay_dict()
            else:
                params['biz_error_code'] = self.biz_error_code
        if self.biz_error_msg:
            if hasattr(self.biz_error_msg, 'to_alipay_dict'):
                params['biz_error_msg'] = self.biz_error_msg.to_alipay_dict()
            else:
                params['biz_error_msg'] = self.biz_error_msg
        if self.business_type:
            if hasattr(self.business_type, 'to_alipay_dict'):
                params['business_type'] = self.business_type.to_alipay_dict()
            else:
                params['business_type'] = self.business_type
        if self.check_code:
            if hasattr(self.check_code, 'to_alipay_dict'):
                params['check_code'] = self.check_code.to_alipay_dict()
            else:
                params['check_code'] = self.check_code
        if self.create_result:
            if hasattr(self.create_result, 'to_alipay_dict'):
                params['create_result'] = self.create_result.to_alipay_dict()
            else:
                params['create_result'] = self.create_result
        if self.device_no:
            if hasattr(self.device_no, 'to_alipay_dict'):
                params['device_no'] = self.device_no.to_alipay_dict()
            else:
                params['device_no'] = self.device_no
        if self.invoice_amount:
            if hasattr(self.invoice_amount, 'to_alipay_dict'):
                params['invoice_amount'] = self.invoice_amount.to_alipay_dict()
            else:
                params['invoice_amount'] = self.invoice_amount
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_date:
            if hasattr(self.invoice_date, 'to_alipay_dict'):
                params['invoice_date'] = self.invoice_date.to_alipay_dict()
            else:
                params['invoice_date'] = self.invoice_date
        if self.invoice_file_content:
            if hasattr(self.invoice_file_content, 'to_alipay_dict'):
                params['invoice_file_content'] = self.invoice_file_content.to_alipay_dict()
            else:
                params['invoice_file_content'] = self.invoice_file_content
        if self.invoice_file_type:
            if hasattr(self.invoice_file_type, 'to_alipay_dict'):
                params['invoice_file_type'] = self.invoice_file_type.to_alipay_dict()
            else:
                params['invoice_file_type'] = self.invoice_file_type
        if self.invoice_items:
            if hasattr(self.invoice_items, 'to_alipay_dict'):
                params['invoice_items'] = self.invoice_items.to_alipay_dict()
            else:
                params['invoice_items'] = self.invoice_items
        if self.invoice_kind:
            if hasattr(self.invoice_kind, 'to_alipay_dict'):
                params['invoice_kind'] = self.invoice_kind.to_alipay_dict()
            else:
                params['invoice_kind'] = self.invoice_kind
        if self.invoice_memo:
            if hasattr(self.invoice_memo, 'to_alipay_dict'):
                params['invoice_memo'] = self.invoice_memo.to_alipay_dict()
            else:
                params['invoice_memo'] = self.invoice_memo
        if self.invoice_no:
            if hasattr(self.invoice_no, 'to_alipay_dict'):
                params['invoice_no'] = self.invoice_no.to_alipay_dict()
            else:
                params['invoice_no'] = self.invoice_no
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.levy_type:
            if hasattr(self.levy_type, 'to_alipay_dict'):
                params['levy_type'] = self.levy_type.to_alipay_dict()
            else:
                params['levy_type'] = self.levy_type
        if self.normal_invoice_code:
            if hasattr(self.normal_invoice_code, 'to_alipay_dict'):
                params['normal_invoice_code'] = self.normal_invoice_code.to_alipay_dict()
            else:
                params['normal_invoice_code'] = self.normal_invoice_code
        if self.normal_invoice_no:
            if hasattr(self.normal_invoice_no, 'to_alipay_dict'):
                params['normal_invoice_no'] = self.normal_invoice_no.to_alipay_dict()
            else:
                params['normal_invoice_no'] = self.normal_invoice_no
        if self.payee_address:
            if hasattr(self.payee_address, 'to_alipay_dict'):
                params['payee_address'] = self.payee_address.to_alipay_dict()
            else:
                params['payee_address'] = self.payee_address
        if self.payee_bank_account_id:
            if hasattr(self.payee_bank_account_id, 'to_alipay_dict'):
                params['payee_bank_account_id'] = self.payee_bank_account_id.to_alipay_dict()
            else:
                params['payee_bank_account_id'] = self.payee_bank_account_id
        if self.payee_bank_name:
            if hasattr(self.payee_bank_name, 'to_alipay_dict'):
                params['payee_bank_name'] = self.payee_bank_name.to_alipay_dict()
            else:
                params['payee_bank_name'] = self.payee_bank_name
        if self.payee_checker:
            if hasattr(self.payee_checker, 'to_alipay_dict'):
                params['payee_checker'] = self.payee_checker.to_alipay_dict()
            else:
                params['payee_checker'] = self.payee_checker
        if self.payee_name:
            if hasattr(self.payee_name, 'to_alipay_dict'):
                params['payee_name'] = self.payee_name.to_alipay_dict()
            else:
                params['payee_name'] = self.payee_name
        if self.payee_operator:
            if hasattr(self.payee_operator, 'to_alipay_dict'):
                params['payee_operator'] = self.payee_operator.to_alipay_dict()
            else:
                params['payee_operator'] = self.payee_operator
        if self.payee_phone:
            if hasattr(self.payee_phone, 'to_alipay_dict'):
                params['payee_phone'] = self.payee_phone.to_alipay_dict()
            else:
                params['payee_phone'] = self.payee_phone
        if self.payee_receiver:
            if hasattr(self.payee_receiver, 'to_alipay_dict'):
                params['payee_receiver'] = self.payee_receiver.to_alipay_dict()
            else:
                params['payee_receiver'] = self.payee_receiver
        if self.payee_register_no:
            if hasattr(self.payee_register_no, 'to_alipay_dict'):
                params['payee_register_no'] = self.payee_register_no.to_alipay_dict()
            else:
                params['payee_register_no'] = self.payee_register_no
        if self.payer_address:
            if hasattr(self.payer_address, 'to_alipay_dict'):
                params['payer_address'] = self.payer_address.to_alipay_dict()
            else:
                params['payer_address'] = self.payer_address
        if self.payer_bank_account_id:
            if hasattr(self.payer_bank_account_id, 'to_alipay_dict'):
                params['payer_bank_account_id'] = self.payer_bank_account_id.to_alipay_dict()
            else:
                params['payer_bank_account_id'] = self.payer_bank_account_id
        if self.payer_bank_name:
            if hasattr(self.payer_bank_name, 'to_alipay_dict'):
                params['payer_bank_name'] = self.payer_bank_name.to_alipay_dict()
            else:
                params['payer_bank_name'] = self.payer_bank_name
        if self.payer_email:
            if hasattr(self.payer_email, 'to_alipay_dict'):
                params['payer_email'] = self.payer_email.to_alipay_dict()
            else:
                params['payer_email'] = self.payer_email
        if self.payer_name:
            if hasattr(self.payer_name, 'to_alipay_dict'):
                params['payer_name'] = self.payer_name.to_alipay_dict()
            else:
                params['payer_name'] = self.payer_name
        if self.payer_phone:
            if hasattr(self.payer_phone, 'to_alipay_dict'):
                params['payer_phone'] = self.payer_phone.to_alipay_dict()
            else:
                params['payer_phone'] = self.payer_phone
        if self.payer_register_no:
            if hasattr(self.payer_register_no, 'to_alipay_dict'):
                params['payer_register_no'] = self.payer_register_no.to_alipay_dict()
            else:
                params['payer_register_no'] = self.payer_register_no
        if self.platform_code:
            if hasattr(self.platform_code, 'to_alipay_dict'):
                params['platform_code'] = self.platform_code.to_alipay_dict()
            else:
                params['platform_code'] = self.platform_code
        if self.platform_tid:
            if hasattr(self.platform_tid, 'to_alipay_dict'):
                params['platform_tid'] = self.platform_tid.to_alipay_dict()
            else:
                params['platform_tid'] = self.platform_tid
        if self.platform_user_id:
            if hasattr(self.platform_user_id, 'to_alipay_dict'):
                params['platform_user_id'] = self.platform_user_id.to_alipay_dict()
            else:
                params['platform_user_id'] = self.platform_user_id
        if self.qr_code:
            if hasattr(self.qr_code, 'to_alipay_dict'):
                params['qr_code'] = self.qr_code.to_alipay_dict()
            else:
                params['qr_code'] = self.qr_code
        if self.receive_mobile:
            if hasattr(self.receive_mobile, 'to_alipay_dict'):
                params['receive_mobile'] = self.receive_mobile.to_alipay_dict()
            else:
                params['receive_mobile'] = self.receive_mobile
        if self.red_notice_no:
            if hasattr(self.red_notice_no, 'to_alipay_dict'):
                params['red_notice_no'] = self.red_notice_no.to_alipay_dict()
            else:
                params['red_notice_no'] = self.red_notice_no
        if self.serial_no:
            if hasattr(self.serial_no, 'to_alipay_dict'):
                params['serial_no'] = self.serial_no.to_alipay_dict()
            else:
                params['serial_no'] = self.serial_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.special_flag:
            if hasattr(self.special_flag, 'to_alipay_dict'):
                params['special_flag'] = self.special_flag.to_alipay_dict()
            else:
                params['special_flag'] = self.special_flag
        if self.sum_price:
            if hasattr(self.sum_price, 'to_alipay_dict'):
                params['sum_price'] = self.sum_price.to_alipay_dict()
            else:
                params['sum_price'] = self.sum_price
        if self.sum_tax:
            if hasattr(self.sum_tax, 'to_alipay_dict'):
                params['sum_tax'] = self.sum_tax.to_alipay_dict()
            else:
                params['sum_tax'] = self.sum_tax
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceApplyInvUploadModel()
        if 'anti_fake_code' in d:
            o.anti_fake_code = d['anti_fake_code']
        if 'apply_id' in d:
            o.apply_id = d['apply_id']
        if 'biz_error_code' in d:
            o.biz_error_code = d['biz_error_code']
        if 'biz_error_msg' in d:
            o.biz_error_msg = d['biz_error_msg']
        if 'business_type' in d:
            o.business_type = d['business_type']
        if 'check_code' in d:
            o.check_code = d['check_code']
        if 'create_result' in d:
            o.create_result = d['create_result']
        if 'device_no' in d:
            o.device_no = d['device_no']
        if 'invoice_amount' in d:
            o.invoice_amount = d['invoice_amount']
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_date' in d:
            o.invoice_date = d['invoice_date']
        if 'invoice_file_content' in d:
            o.invoice_file_content = d['invoice_file_content']
        if 'invoice_file_type' in d:
            o.invoice_file_type = d['invoice_file_type']
        if 'invoice_items' in d:
            o.invoice_items = d['invoice_items']
        if 'invoice_kind' in d:
            o.invoice_kind = d['invoice_kind']
        if 'invoice_memo' in d:
            o.invoice_memo = d['invoice_memo']
        if 'invoice_no' in d:
            o.invoice_no = d['invoice_no']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'levy_type' in d:
            o.levy_type = d['levy_type']
        if 'normal_invoice_code' in d:
            o.normal_invoice_code = d['normal_invoice_code']
        if 'normal_invoice_no' in d:
            o.normal_invoice_no = d['normal_invoice_no']
        if 'payee_address' in d:
            o.payee_address = d['payee_address']
        if 'payee_bank_account_id' in d:
            o.payee_bank_account_id = d['payee_bank_account_id']
        if 'payee_bank_name' in d:
            o.payee_bank_name = d['payee_bank_name']
        if 'payee_checker' in d:
            o.payee_checker = d['payee_checker']
        if 'payee_name' in d:
            o.payee_name = d['payee_name']
        if 'payee_operator' in d:
            o.payee_operator = d['payee_operator']
        if 'payee_phone' in d:
            o.payee_phone = d['payee_phone']
        if 'payee_receiver' in d:
            o.payee_receiver = d['payee_receiver']
        if 'payee_register_no' in d:
            o.payee_register_no = d['payee_register_no']
        if 'payer_address' in d:
            o.payer_address = d['payer_address']
        if 'payer_bank_account_id' in d:
            o.payer_bank_account_id = d['payer_bank_account_id']
        if 'payer_bank_name' in d:
            o.payer_bank_name = d['payer_bank_name']
        if 'payer_email' in d:
            o.payer_email = d['payer_email']
        if 'payer_name' in d:
            o.payer_name = d['payer_name']
        if 'payer_phone' in d:
            o.payer_phone = d['payer_phone']
        if 'payer_register_no' in d:
            o.payer_register_no = d['payer_register_no']
        if 'platform_code' in d:
            o.platform_code = d['platform_code']
        if 'platform_tid' in d:
            o.platform_tid = d['platform_tid']
        if 'platform_user_id' in d:
            o.platform_user_id = d['platform_user_id']
        if 'qr_code' in d:
            o.qr_code = d['qr_code']
        if 'receive_mobile' in d:
            o.receive_mobile = d['receive_mobile']
        if 'red_notice_no' in d:
            o.red_notice_no = d['red_notice_no']
        if 'serial_no' in d:
            o.serial_no = d['serial_no']
        if 'source' in d:
            o.source = d['source']
        if 'special_flag' in d:
            o.special_flag = d['special_flag']
        if 'sum_price' in d:
            o.sum_price = d['sum_price']
        if 'sum_tax' in d:
            o.sum_tax = d['sum_tax']
        return o


